#global var NOTE

utils::globalVariables(c("test","Confirmed","Negative","Positive","arthropods","Abundance","Total","PointEstimate","ticks","UpperCI","LowerCI","INTERVAL","pool_id","surv_year" ,"InfectionRate","TrapEvents", "test_target_vector","target_acronym","target_icd_10","status_name","value","collection_date", "sex" ,"num_count","test_target_acronym" , "test_status_name" , "sex_type" ,"trap_acronym","collection_id","trap_problem_bit","trap_nights","num_trap","species_display_name","add_date", "agency_code", "agency_id", "agency_name", "attached", "bloodfed",
                         "collection", "collection_date_end", "collection_date_start", "Year","lures","lures_code","lures_weight","lures_description","collection_num",
                         "comments", "conditions_moisture", "conditions_sunlight", "deactive_date", "host",
                         "humidity","Agency","Trap","Species","Disease","name","Count","pick" ,"identified_by", "test_method_acronym", "test_method_name", "pool_comments",
                         "pool_num", "primary_source", "sample_method_name", "sample_method_value",
                         "sex_name", "site_code", "site_id", "site_name","trapnight_min","trapnight_max","collection_latitude","collection_longitude","pool_latitude","pool_longitude",":=", "species_full_name", "test_target_icd_10",
                         "target_vector","Species", "temperature", "test_agency_code", "test_agency_name",
                         "test_agency_state_acrnym","County","region_type","setNames","subregion","st_within", "test_date", "test_id","VectorIndex" ,"trap_name", "trap_presence",
                         "type", "updated","method_name","method_acronym" ,"where",".data","test_value", "wind_speed","city","sym",".","lures_id","geoid","id", "test_agency_state_acronym","county","namelsad","namelsad.x" ,"postal_code","type.y","namelsad.y","AbundanceCalculation","AbundanceType"))



